# GraphQL Utils

A Python package having utilities for working with GraphQL APIs especially for Gen AI applications in preparing `graph` data for LLMs.

Current scope includes packages:

- **Schema Splitter** A simple util to split a GraphQL schema into smaller sub-graphs in building vector databases. These sub-graphs can be utilized as Retrieval-Augmented Generation (RAG) documents in Generative AI workflows.

## More Information

- [README-dev.md](docs/README-dev.md) - Developer documentation
- [README-templ.md](docs/README-templ.md) - Template repository for GitHub Actions

## Author

Ramesh Doddi, CTO at iRemote, Inc. [Visit iRemote](https://iremote.ai)

## License

This project is open-sourced under the MIT License. See the [LICENSE](LICENSE) file for more details.
